# 从源文件夹中获取所有图片，截取人脸后存入目标文件夹

## 一、安装：

pip install face-cropping

## 二、使用

import face-cropping

import os

import cv2

import dlib

folder_path='input_images'

output_folder='output_folder'

start(folder_path, output_folder)
